# Package for IxLoad Automation 

## To Install:
pip install ixload

## To import into project
from ixload import IxLoadUtils \
from ixload import IxLoadTestSettings \
from ixload import IxRestUtils \
from ixload import IxRestPyUtils
